@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -67,97 +64,119 @@ bool Core99CPU::start(IOService *provider)
   UInt32               maxCPUs, uniNVersion, physCPU;
   ml_processor_info_t  processor_info;
 
-  // callPlatformFunction symbols
-  mpic_getProvider = OSSymbol::withCString("mpic_getProvider");
-  mpic_getIPIVector= OSSymbol::withCString("mpic_getIPIVector");
-  mpic_setCurrentTaskPriority = OSSymbol::withCString("mpic_setCurrentTaskPriority");
-  mpic_setUpForSleep = OSSymbol::withCString("mpic_setUpForSleep");
-  mpic_dispatchIPI = OSSymbol::withCString("mpic_dispatchIPI");
-  keyLargo_restoreRegisterState = OSSymbol::withCString("keyLargo_restoreRegisterState");
-  keyLargo_syncTimeBase = OSSymbol::withCString("keyLargo_syncTimeBase");
-  keyLargo_saveRegisterState = OSSymbol::withCString("keyLargo_saveRegisterState");
-  keyLargo_turnOffIO = OSSymbol::withCString("keyLargo_turnOffIO");
-  keyLargo_writeRegUInt8 = OSSymbol::withCString("keyLargo_writeRegUInt8");
-  
   core99PE = OSDynamicCast(Core99PE, getPlatform());
-  if (core99PE == 0) return false;
+  if (core99PE == 0)
+    return false;
+
+  // callPlatformFunction symbols
+  mpic_getProvider              = OSSymbol::withCString( "mpic_getProvider"              );
+  mpic_getIPIVector             = OSSymbol::withCString( "mpic_getIPIVector"             );
+  mpic_setCurrentTaskPriority   = OSSymbol::withCString( "mpic_setCurrentTaskPriority"   );
+  mpic_setUpForSleep            = OSSymbol::withCString( "mpic_setUpForSleep"            );
+  mpic_dispatchIPI              = OSSymbol::withCString( "mpic_dispatchIPI"              );
+  keyLargo_restoreRegisterState = OSSymbol::withCString( "keyLargo_restoreRegisterState" );
+  keyLargo_syncTimeBase         = OSSymbol::withCString( "keyLargo_syncTimeBase"         );
+  keyLargo_saveRegisterState    = OSSymbol::withCString( "keyLargo_saveRegisterState"    );
+  keyLargo_turnOffIO            = OSSymbol::withCString( "keyLargo_turnOffIO"            );
+  keyLargo_writeRegUInt8        = OSSymbol::withCString( "keyLargo_writeRegUInt8"        );
   
   if (!super::start(provider)) return false;
   
   // Get the Uni-N Version.
   uniNRegEntry = fromPath("/uni-n", gIODTPlane);
-  if (uniNRegEntry == 0) return false;
+  if (uniNRegEntry == 0)
+	return false;
   tmpData = OSDynamicCast(OSData, uniNRegEntry->getProperty("device-rev"));
-  if (tmpData == 0) return false;
+  if (tmpData == 0)
+	return false;
   uniNVersion = *(long *)tmpData->getBytesNoCopy();
   
   // Count the CPUs.
   numCPUs = 0;
   cpusRegEntry = fromPath("/cpus", gIODTPlane);
-  if (cpusRegEntry == 0) return false;
+  if (cpusRegEntry == 0)
+	return false;
   cpusIterator = cpusRegEntry->getChildIterator(gIODTPlane);
-  while (cpusIterator->getNextObject()) numCPUs++;
+  while (cpusIterator->getNextObject())
+	numCPUs++;
   cpusIterator->release();
   
   // Limit the number of CPUs to one if uniNVersion is 1.0.7 or less.
-  if (uniNVersion < kUniNVersion107) numCPUs = 1;
+  if (uniNVersion < kUniNVersion107)
+	numCPUs = 1;
   
   // Limit the number of CPUs by the cpu=# boot arg.
-  if (PE_parse_boot_arg("cpus", &maxCPUs)) {
-    if (numCPUs > maxCPUs) numCPUs = maxCPUs;
+  if ( PE_parse_boot_arg("cpus", &maxCPUs) )
+  {
+    if (numCPUs > maxCPUs)
+	numCPUs = maxCPUs;
   }
   
   // Get the "flush-on-lock" property from the fisrt cpu node.
   flushOnLock = false;
   cpusRegEntry = fromPath("/cpus/@0", gIODTPlane);
-  if (cpusRegEntry == 0) return false;
-  if (cpusRegEntry->getProperty("flush-on-lock") != 0) flushOnLock = true;
+  if (cpusRegEntry == 0)
+	return false;
+  if (cpusRegEntry->getProperty("flush-on-lock") != 0)
+	flushOnLock = true;
   
   // Set flushOnLock when numCPUs is not one.
-  if (numCPUs != 1) flushOnLock = true;
+  if (numCPUs != 1)
+	flushOnLock = true;
   
   // Get the physical CPU number from the "reg" property.
   tmpData = OSDynamicCast(OSData, provider->getProperty("reg"));
-  if (tmpData == 0) return false;
+  if (tmpData == 0)
+	return false;
   physCPU = *(long *)tmpData->getBytesNoCopy();
   setCPUNumber(physCPU);
   
   // Find out if this is the boot CPU.
   bootCPU = false;
   tmpData = OSDynamicCast(OSData, provider->getProperty("state"));
-  if (tmpData == 0) return false;
-  if (!strcmp((char *)tmpData->getBytesNoCopy(), "running")) bootCPU = true;
+  if (tmpData == 0)
+	return false;
+  if (!strcmp((char *)tmpData->getBytesNoCopy(), "running"))
+	bootCPU = true;
   
-  if (bootCPU) {
+  if (bootCPU)
+  {
     gCPUIC = new IOCPUInterruptController;
-    if (gCPUIC == 0) return false;
+    if (gCPUIC == 0)
+	return false;
     if (gCPUIC->initCPUInterruptController(numCPUs) != kIOReturnSuccess)
-      return false;
+	return false;
     gCPUIC->attach(this);
     gCPUIC->registerCPUInterruptController();
   }
   
   // Get the l2cr value from the property list.
   tmpData = OSDynamicCast(OSData, provider->getProperty("l2cr"));
-  if (tmpData != 0) {
+  if (tmpData != 0)
+  {
     l2crValue = *(long *)tmpData->getBytesNoCopy() & 0x7FFFFFFF;
-  } else {
+  }
+  else
+  {
     l2crValue = mfl2cr() & 0x7FFFFFFF;
   }
   
   // Wait for KeyLargo to show up.
   keyLargo = waitForService(serviceMatching("KeyLargo"));
-  if (keyLargo == 0) return false;
+  if (keyLargo == 0)
+	return false;
   
   // Wait for MPIC to show up.
   mpic = waitForService(serviceMatching("AppleMPICInterruptController"));
-  if (mpic == 0) return false;
+  if (mpic == 0)
+	return false;
   
   // Set the Interrupt Properties for this cpu.
   mpic->callPlatformFunction(mpic_getProvider, false, (void *)&mpicRegEntry, 0, 0, 0);
   interruptControllerName = IODTInterruptControllerName(mpicRegEntry);
   mpic->callPlatformFunction(mpic_getIPIVector, false, (void *)&physCPU, (void *)&interruptData, 0, 0);
-  if ((interruptControllerName == 0) || (interruptData == 0)) return false;
+  if ((interruptControllerName == 0) || (interruptData == 0))
+	return false;
   
   tmpArray = OSArray::withCapacity(1);
   tmpArray->setObject(interruptControllerName);
@@ -171,19 +190,19 @@ bool Core99CPU::start(IOService *provider)
   
   setCPUState(kIOCPUStateUninitalized);
   
-  if (physCPU < numCPUs) {
+  if (physCPU < numCPUs)
+  {
     processor_info.cpu_id           = (cpu_id_t)this;
     processor_info.boot_cpu         = bootCPU;
     processor_info.start_paddr      = 0x0100;
     processor_info.l2cr_value       = l2crValue;
     processor_info.supports_nap     = !flushOnLock;
-    processor_info.time_base_enable =
-      (time_base_enable_t)&Core99CPU::enableCPUTimeBase;
+    processor_info.time_base_enable = (time_base_enable_t)&Core99CPU::enableCPUTimeBase;
     
     // Register this CPU with mach.
-    result = ml_processor_register(&processor_info, &machProcessor,
-				   &ipi_handler);
-    if (result == KERN_FAILURE) return false;
+    result = ml_processor_register(&processor_info, &machProcessor, &ipi_handler);
+    if (result == KERN_FAILURE)
+	return false;
     
     processor_start(machProcessor);
   }
@@ -192,7 +211,8 @@ bool Core99CPU::start(IOService *provider)
   // will not shutdown the system while going to sleep:
   service = waitForService(serviceMatching("IOPMrootDomain"));
   IOPMrootDomain *pmRootDomain = OSDynamicCast(IOPMrootDomain, service);
-  if (pmRootDomain != 0) {
+  if (pmRootDomain != 0)
+  {
       kprintf("Register Core99CPU %d to acknowledge power changes\n", getCPUNumber());
       pmRootDomain->registerInterestedDriver(this);
   }
@@ -207,22 +227,29 @@ bool Core99CPU::start(IOService *provider)
 // re-enable it before to go up:
 IOReturn Core99CPU::powerStateWillChangeTo ( IOPMPowerFlags theFlags, unsigned long, IOService*)
 {
-    if ( ! (theFlags & IOPMPowerOn) ) {
+    if ( ! (theFlags & IOPMPowerOn) )
+    {
         // Sleep sequence:
-        kprintf("Core99CPU %d powerStateWillChangeTo to acknowledge power changes (DOWN) we set napping %d\n", getCPUNumber(), false);
-        rememberNap = ml_enable_nap(getCPUNumber(), false);        // Disable napping (the function returns the previous state)
+        kprintf("Core99CPU %d powerStateWillChangeTo to acknowledge power changes (DOWN) we set napping %d\n",
+			getCPUNumber(), false);
+        // Disable napping (the function returns the previous state)
+        rememberNap = ml_enable_nap(getCPUNumber(), false);
     }
-    else {
+    else
+    {
         // Wake sequence:
-        kprintf("Core99CPU %d powerStateWillChangeTo to acknowledge power changes (UP) we set napping %d\n", getCPUNumber(), rememberNap);
-        ml_enable_nap(getCPUNumber(), rememberNap); 		   // Re-set the nap as it was before.
+        kprintf("Core99CPU %d powerStateWillChangeTo to acknowledge power changes (UP) we set napping %d\n",
+			getCPUNumber(), rememberNap);
+        // Re-set the nap as it was before.
+        ml_enable_nap(getCPUNumber(), rememberNap);
     }
     return IOPMAckImplied;
 }
 
 void Core99CPU::initCPU(bool boot)
 {
-  if (!boot && bootCPU) {
+  if (!boot && bootCPU)
+  {
     // Tell Uni-N to enter normal mode.
     core99PE->writeUniNReg(kUniNPowerMngmnt, kUniNNormal);
     
@@ -235,7 +262,8 @@ void Core99CPU::initCPU(bool boot)
     keyLargo->callPlatformFunction(keyLargo_restoreRegisterState, false, 0, 0, 0, 0);
     
     if ((core99PE->getMachineType() == kCore99TypePowerMac3_1) ||
-        (core99PE->getMachineType() == kCore99TypePowerMac3_3)) {
+        (core99PE->getMachineType() == kCore99TypePowerMac3_3))
+    {
         // Disables the interrupts for this CPU.
         kprintf("Core99CPU::initCPU %d -> mpic->setUpForSleep on", getCPUNumber());
         mpic->callPlatformFunction(mpic_setUpForSleep, false, (void *)false, (void *)getCPUNumber(), 0, 0);
@@ -248,15 +276,17 @@ void Core99CPU::initCPU(bool boot)
   if (bootCPU)
         keyLargo->callPlatformFunction(keyLargo_syncTimeBase, false, 0, 0, 0, 0);
   
-  if (boot) {
+  if (boot)
+  {
   
     gCPUIC->enableCPUInterrupt(this);
     
     // Register and enable IPIs.
-    cpuNub->registerInterrupt(0, this,
-			      (IOInterruptAction)&Core99CPU::ipiHandler, 0);
+    cpuNub->registerInterrupt(0, this, (IOInterruptAction)&Core99CPU::ipiHandler, 0);
     cpuNub->enableInterrupt(0);
-  } else {
+  }
+  else
+  {
     long priority = 0;
     mpic->callPlatformFunction(mpic_setCurrentTaskPriority, false, (void *)&priority, 0, 0, 0);
   }
@@ -267,7 +297,8 @@ void Core99CPU::initCPU(bool boot)
 
 void Core99CPU::quiesceCPU(void)
 {
-    if (bootCPU) {
+    if (bootCPU)
+    {
         // Send PMU command to shutdown system before io is turned off
         if (pmu != 0)
             pmu->callPlatformFunction("sleepNow", false, 0, 0, 0, 0);
@@ -275,7 +306,8 @@ void Core99CPU::quiesceCPU(void)
             kprintf("Core99CPU::quiesceCPU can't find ApplePMU\n");
     
         if ((core99PE->getMachineType() == kCore99TypePowerMac3_1) ||
-            (core99PE->getMachineType() == kCore99TypePowerMac3_3)) {
+            (core99PE->getMachineType() == kCore99TypePowerMac3_3))
+	{
             // Disables the interrupts for this CPU.
             kprintf("Core99CPU::quiesceCPU %d -> mpic->setUpForSleep off", getCPUNumber());
             mpic->callPlatformFunction(mpic_setUpForSleep, false, (void *)true, (void *)getCPUNumber(), 0, 0);
@@ -302,12 +334,12 @@ void Core99CPU::quiesceCPU(void)
     ml_ppc_sleep();
 }
 
-kern_return_t Core99CPU::startCPU(vm_offset_t /*start_paddr*/,
-				  vm_offset_t /*arg_paddr*/)
+kern_return_t Core99CPU::startCPU(vm_offset_t /*start_paddr*/, vm_offset_t /*arg_paddr*/)
 {
   long gpioOffset;
   
-  switch (getCPUNumber()) {
+  switch (getCPUNumber())
+  {
   case 0 : gpioOffset = 0x5B; break;
   case 1 : gpioOffset = 0x5C; break;
   case 2 : gpioOffset = 0x67; break;
@@ -329,12 +361,14 @@ void Core99CPU::haltCPU(void)
   
   setCPUState(kIOCPUStateStopped);
   
-  if (bootCPU) {
+  if (bootCPU)
+  {
     // Find the DEC Bridge if it is there.
     decBridge = 0;
     decBridgeEntry = fromPath("/pci@f2000000/@d", gIODTPlane);
     decBridgeNub = OSDynamicCast(IOService, decBridgeEntry);
-    if (decBridgeNub != 0) {
+    if (decBridgeNub != 0)
+    {
       decBridge = OSDynamicCast(IOPCI2PCIBridge, decBridgeNub->getClient());
     }
   }
